@@ -135,6 +135,18 @@ void TestQuaZipFile::zipUnzip()
         QCOMPARE(archivedData, originalData);
         testUnzip.goToNextFile();
     }
+    if (!password.isEmpty()) {
+        QVERIFY(testUnzip.goToFirstFile());
+        QuaZipFileInfo64 info;
+        QVERIFY(testUnzip.getCurrentFileInfo(&info));
+        QFile original("tmp/" + info.name);
+        QVERIFY(original.open(QIODevice::ReadOnly));
+        QuaZipFile archived(&testUnzip);
+        QVERIFY(archived.open(QIODevice::ReadOnly, "WrongPassword"));
+        QByteArray originalData = original.readAll();
+        QByteArray archivedData = archived.readAll();
+        QVERIFY(archivedData != originalData);
+    }
     testUnzip.close();
     QCOMPARE(testUnzip.getZipError(), UNZ_OK);
     // clean up
@@ -325,7 +337,7 @@ void TestQuaZipFile::setFileName()
     QVERIFY(createTestArchive(testZipName, QStringList() << testFileName));
     QuaZipFile testFile(testZipName);
     testFile.setFileName(testFileName.toUpper());
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN
     QVERIFY(testFile.open(QIODevice::ReadOnly));
     testFile.close();
 #else
@@ -512,4 +524,6 @@ void TestQuaZipFile::largeFile()
     QCOMPARE(fakeLargeZip.getFileInfoList().size(), numFiles);
     QCOMPARE(fakeLargeZip.getFileInfoList()[0].uncompressedSize,
             static_cast<quint32>(0));
+    fakeLargeZip.close();
+    curDir.remove("tmp/large.zip");
 }
